:notoc:

#############################################
`skarf` documentation
#############################################

**Date**: |today| **Version**: |version|

**Useful links**:
`GitHub <https://github.com/childmindresearch/skarf>`__ |
`Issues & Ideas <https://github.com/childmindresearch/skarf/issues>`__ |
`Q&A Support <https://github.com/childmindresearch/skarf/discussions>`__ |


skarf (**s**\ ci\ **k**\ it **\ a**\ uto **r**\ egressive models for **f**\ unctional connectivity) is
a Python package for regularized vector autoregressive (VAR) time series modeling built
on top of `scikit-learn <https://scikit-learn.org>`_.


.. grid:: 1 2 2 2
    :gutter: 4
    :padding: 2 2 0 0
    :class-container: sd-text-center

    .. grid-item-card:: Getting started
        :img-top: _static/img/index_getting_started.svg
        :class-card: intro-card
        :shadow: md

        Install `skarf` and get started with basic usage.

        +++

        .. button-ref:: quick_start
            :ref-type: ref
            :click-parent:
            :color: secondary
            :expand:

            To the getting started guide

    .. grid-item-card::  User guide
        :img-top: _static/img/index_user_guide.svg
        :class-card: intro-card
        :shadow: md

        The user guide provides a more in-depth tour of `skarf` functionality.

        +++

        .. button-ref:: user_guide
            :ref-type: ref
            :click-parent:
            :color: secondary
            :expand:

            To the user guide

    .. grid-item-card::  API reference
        :img-top: _static/img/index_api.svg
        :class-card: intro-card
        :shadow: md

        The API reference contains a detailed description of all the estimators and
        other utilities provided by `skarf`.

        +++

        .. button-ref:: api
            :ref-type: ref
            :click-parent:
            :color: secondary
            :expand:

            To the API reference

    .. grid-item-card::  Examples
        :img-top: _static/img/index_examples.svg
        :class-card: intro-card
        :shadow: md

        The gallery of examples shows off `skarf` in action.

        +++

        .. button-ref:: general_examples
            :ref-type: ref
            :click-parent:
            :color: secondary
            :expand:

            To the gallery of examples


.. toctree::
    :maxdepth: 3
    :hidden:
    :titlesonly:

    quick_start
    user_guide
    api/index
    auto_examples/index
